# COMPAS GMSH

**THIS PROJECT IS WIP.**

**CONTRIBUTIONS TOWARDS CREATING A FIRST STABLE VERSION A VERY WELCOME :)...**

----

COMPAS friendly interface for Python-GMSH.

## Installation

```bash
conda create -n gmsh -c conda-forge compas compas_view2 --yes
conda activate gmsh
pip install gmsh compas_gmsh
```

## Getting Started

Have a look at some of the first [examples in the documentation](https://compas.dev/compas_gmsh/latest/examples.html).

## License

`compas_gmsh` provides a COMPAS friendly interface to `Gmsh`.
`Gmsh` is released under GPL-2.0-or-later.
